
#ifndef _MFBMAP_H
#define _MFBMAP_H

#define InverseAlu  xf1bppInverseAlu
#define endtab  xf1bppendtab
#define mask  xf1bppmask
#define mergeRopBits  xf1bppmergeRopBits
#define mergeGetRopBits  xf1bppmergeGetRopBits
#define mfbAllocatePrivates  xf1bppAllocatePrivates
#define mfbBSFuncRec  xf1bppBSFuncRec
#define mfbBlackSolidFS  xf1bppBlackSolidFS
#define mfbBlackStippleFS  xf1bppBlackStippleFS
#define mfbBresD  xf1bppBresD
#define mfbBresS  xf1bppBresS
#define mfbChangeWindowAttributes  xf1bppChangeWindowAttributes
#define mfbCloseScreen  xf1bppCloseScreen
#define mfbCopyArea  xf1bppCopyArea
#define mfbCopyPixmap  xf1bppCopyPixmap
#define mfbCopyPlane  xf1bppCopyPlane
#define mfbCopyRotatePixmap  xf1bppCopyRotatePixmap
#define mfbCopyWindow  xf1bppCopyWindow
#define mfbCreateColormap  xf1bppCreateColormap
#define mfbCreateDefColormap  xf1bppCreateDefColormap
#define mfbCreateGC  xf1bppCreateGC
#define mfbCreatePixmap  xf1bppCreatePixmap
#define mfbCreateWindow  xf1bppCreateWindow
#define mfbDestroyColormap  xf1bppDestroyColormap
#define mfbDestroyPixmap  xf1bppDestroyPixmap
#define mfbDestroyWindow  xf1bppDestroyWindow
#define mfbDoBitblt  xf1bppDoBitblt
#define mfbDoBitbltCopy  xf1bppDoBitbltCopy
#define mfbDoBitbltCopyInverted  xf1bppDoBitbltCopyInverted
#define mfbDoBitbltGeneral  xf1bppDoBitbltGeneral
#define mfbDoBitbltOr  xf1bppDoBitbltOr
#define mfbDoBitbltXor  xf1bppDoBitbltXor
#define mfbFillInScreen  xf1bppFillInScreen
#define mfbFillPolyBlack  xf1bppFillPolyBlack
#define mfbFillPolyInvert  xf1bppFillPolyInvert
#define mfbFillPolyWhite  xf1bppFillPolyWhite
#define mfbGCPrivateIndex  xf1bppGCPrivateIndex
#define mfbGetGCPrivateIndex  xf1bppGetGCPrivateIndex
#define mfbGetImage  xf1bppGetImage
#define mfbGetInverseAlu xf1bppGetInverseAlu
#define mfbGetSpans  xf1bppGetSpans
#define mfbGetWindowPixmap  xf1bppGetWindowPixmap
#define mfbGetWindowPrivateIndex  xf1bppGetWindowPrivateIndex
#define mfbGetmask  xf1bppGetmask
#define mfbGetpartmasks xf1bppGetpartmasks
#define mfbGetrmask  xf1bppGetrmask
#define mfbGetstarttab  xf1bppGetstarttab
#define mfbGetendtab  xf1bppGetendtab
#define mfbHorzS  xf1bppHorzS
#define mfbImageGlyphBltBlack  xf1bppImageGlyphBltBlack
#define mfbImageGlyphBltWhite  xf1bppImageGlyphBltWhite
#define mfbInstallColormap  xf1bppInstallColormap
#define mfbInvertSolidFS  xf1bppInvertSolidFS
#define mfbInvertStippleFS  xf1bppInvertStippleFS
#define mfbLineSD  xf1bppLineSD
#define mfbLineSS  xf1bppLineSS
#define mfbListInstalledColormaps  xf1bppListInstalledColormaps
#define mfbMapWindow  xf1bppMapWindow
#define mfbPadPixmap  xf1bppPadPixmap
#define mfbPixmapToRegion  xf1bppPixmapToRegion
#define mfbPixmapToRegionWeak xf1bppPixmapToRegionWeak
#define mfbPolyFillArcSolid  xf1bppPolyFillArcSolid
#define mfbPolyFillRect  xf1bppPolyFillRect
#define mfbPolyGlyphBltBlack  xf1bppPolyGlyphBltBlack
#define mfbPolyGlyphBltInvert  xf1bppPolyGlyphBltInvert
#define mfbPolyGlyphBltWhite  xf1bppPolyGlyphBltWhite
#define mfbPolyPoint  xf1bppPolyPoint
#define mfbPositionWindow  xf1bppPositionWindow
#define mfbPushPixels  xf1bppPushPixels
#define mfbPushPixelsWeak  xf1bppPushPixelsWeak
#define mfbPutImage  xf1bppPutImage
#define mfbQueryBestSize  xf1bppQueryBestSize
#define mfbQueryBestSizeWeak  xf1bppQueryBestSizeWeak
#define mfbRealizeFont  xf1bppRealizeFont
#define mfbRealizeFontWeak  xf1bppRealizeFontWeak
#define mfbReduceRop  xf1bppReduceRop
#define mfbRegisterCopyPlaneProc  xf1bppRegisterCopyPlaneProc
#define mfbResolveColor  xf1bppResolveColor
#define mfbRestoreAreas  xf1bppRestoreAreas
#define mfbSaveAreas  xf1bppSaveAreas
#define mfbScreenInit  xf1bppScreenInit
#define mfbSegmentSD  xf1bppSegmentSD
#define mfbSegmentSS  xf1bppSegmentSS
#define mfbSetScanline  xf1bppSetScanline
#define mfbSetSpans  xf1bppSetSpans
#define mfbSetWindowPixmap  xf1bppSetWindowPixmap
#define mfbSolidBlackArea  xf1bppSolidBlackArea
#define mfbSolidInvertArea  xf1bppSolidInvertArea
#define mfbSolidPP  xf1bppSolidPP
#define mfbSolidWhiteArea  xf1bppSolidWhiteArea
#define mfbStippleBlackArea  xf1bppStippleBlackArea
#define mfbStippleInvertArea  xf1bppStippleInvertArea
#define mfbStippleWhiteArea  xf1bppStippleWhiteArea
#define mfbTEGlyphBltBlack  xf1bppTEGlyphBltBlack
#define mfbTEGlyphBltWhite  xf1bppTEGlyphBltWhite
#define mfbTileAreaPPW  xf1bppTileAreaPPW
#define mfbTileAreaPPWCopy  xf1bppTileAreaPPWCopy
#define mfbTileAreaPPWGeneral  xf1bppTileAreaPPWGeneral
#define mfbTileFS  xf1bppTileFS
#define mfbUninstallColormap  xf1bppUninstallColormap
#define mfbUnmapWindow  xf1bppUnmapWindow
#define mfbUnnaturalStippleFS  xf1bppUnnaturalStippleFS
#define mfbUnnaturalTileFS  xf1bppUnnaturalTileFS
#define mfbUnrealizeFont  xf1bppUnrealizeFont
#define mfbUnrealizeFontWeak  xf1bppUnrealizeFontWeak
#define mfbValidateGC  xf1bppValidateGC
#define mfbVertS  xf1bppVertS
#define mfbWhiteSolidFS  xf1bppWhiteSolidFS
#define mfbWhiteStippleFS  xf1bppWhiteStippleFS
#define mfbWindowPrivateIndex  xf1bppWindowPrivateIndex
#define mfbXRotatePixmap  xf1bppXRotatePixmap
#define mfbYRotatePixmap  xf1bppYRotatePixmap
#define mfbZeroPolyArcSS  xf1bppZeroPolyArcSS
#define partmasks  xf1bpppartmasks
#define rmask  xf1bpprmask
#define starttab  xf1bppstarttab

#endif
