
#ifdef _MFBMAP_H
#undef _MFBMAP_H

#undef InverseAlu
#undef endtab
#undef mask
#undef mergeRopBits
#undef mergeGetRopBits
#undef mfbAllocatePrivates
#undef mfbBSFuncRec
#undef mfbBlackSolidFS
#undef mfbBlackStippleFS
#undef mfbBresD
#undef mfbBresS
#undef mfbChangeWindowAttributes
#undef mfbCloseScreen
#undef mfbCopyArea
#undef mfbCopyPixmap
#undef mfbCopyPlane
#undef mfbCopyRotatePixmap
#undef mfbCopyWindow
#undef mfbCreateColormap
#undef mfbCreateDefColormap
#undef mfbCreateGC
#undef mfbCreatePixmap
#undef mfbCreateWindow
#undef mfbDestroyColormap
#undef mfbDestroyPixmap
#undef mfbDestroyWindow
#undef mfbDoBitblt
#undef mfbDoBitbltCopy
#undef mfbDoBitbltCopyInverted
#undef mfbDoBitbltGeneral
#undef mfbDoBitbltOr
#undef mfbDoBitbltXor
#undef mfbFillPolyBlack
#undef mfbFillPolyInvert
#undef mfbFillPolyWhite
#undef mfbGCPrivateIndex
#undef mfbGetImage
#undef mfbGetInverseAlu
#undef mfbGetSpans
#undef mfbGetWindowPixmap
#undef mfbHorzS
#undef mfbImageGlyphBltBlack
#undef mfbImageGlyphBltWhite
#undef mfbInstallColormap
#undef mfbInvertSolidFS
#undef mfbInvertStippleFS
#undef mfbLineSD
#undef mfbLineSS
#undef mfbListInstalledColormaps
#undef mfbMapWindow
#undef mfbPadPixmap
#undef mfbPixmapToRegion
#undef mfbPixmapToRegionWeak
#undef mfbPolyFillArcSolid
#undef mfbPolyFillRect
#undef mfbPolyGlyphBltBlack
#undef mfbPolyGlyphBltInvert
#undef mfbPolyGlyphBltWhite
#undef mfbPolyPoint
#undef mfbPositionWindow
#undef mfbPushPixels
#undef mfbPushPixelsWeak
#undef mfbPutImage
#undef mfbQueryBestSize
#undef mfbQueryBestSizeWeak
#undef mfbRealizeFont
#undef mfbRealizeFontWeak
#undef mfbReduceRop
#undef mfbRegisterCopyPlaneProc
#undef mfbResolveColor
#undef mfbRestoreAreas
#undef mfbSaveAreas
#undef mfbScreenInit
#undef mfbSegmentSD
#undef mfbSegmentSS
#undef mfbSetScanline
#undef mfbSetSpans
#undef mfbSetWindowPixmap
#undef mfbSolidBlackArea
#undef mfbSolidInvertArea
#undef mfbSolidPP
#undef mfbSolidWhiteArea
#undef mfbStippleBlackArea
#undef mfbStippleInvertArea
#undef mfbStippleWhiteArea
#undef mfbTEGlyphBltBlack
#undef mfbTEGlyphBltWhite
#undef mfbTileAreaPPW
#undef mfbTileAreaPPWCopy
#undef mfbTileAreaPPWGeneral
#undef mfbTileFS
#undef mfbUninstallColormap
#undef mfbUnmapWindow
#undef mfbUnnaturalStippleFS
#undef mfbUnnaturalTileFS
#undef mfbUnrealizeFont
#undef mfbUnrealizeFontWeak
#undef mfbValidateGC
#undef mfbVertS
#undef mfbWhiteSolidFS
#undef mfbWhiteStippleFS
#undef mfbWindowPrivateIndex
#undef mfbXRotatePixmap
#undef mfbYRotatePixmap
#undef mfbZeroPolyArcSS
#undef partmasks
#undef rmask
#undef starttab

#endif
